# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.2] - 2025-09-23

### Added
- more rdkit functions (still incomplete)

### Changed
- **Docker Compose**: Fixed compose link references

### Removed
- **CI/CD**: Removed CodeQL workflow


## [0.0.1] - 2025-09-22

### Added
- Initial release of molalchemy
- Basic SQLAlchemy extensions for chemical cartridges
- Support for RDKit and Bingo PostgreSQL cartridges
- Core type system for molecular data
- Basic documentation and project structure
